@@ -1,4 +1,4 @@
-from perfect_information_game.utils import get_training_path, ActiveGame as GameClass
+from perfect_information_game.games import Chess as GameClass
 from perfect_information_game.move_selection import TablebaseChooser
 from perfect_information_game.ui import PygameUI
 from time import sleep
